import 'package:flutter/material.dart';

/// 종료된 방에서 "방 정보 보기" 버튼을 누르면 표시되는 읽기전용 모달 (수정판)
class RoomSettingFinishDialog extends StatelessWidget {
  final Map<String, dynamic> roomInfo;

  const RoomSettingFinishDialog({
    Key? key,
    required this.roomInfo,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final media = MediaQuery.of(context);
    final String roomTitle   = (roomInfo['room_title']       ?? '') as String;
    final String roomIntro   = (roomInfo['room_intro']       ?? '') as String;
    final String openYn      = (roomInfo['open_yn']          ?? 'Y') as String;
    final int    maxPeople   = (roomInfo['number_of_people'] ?? 0) as int;
    final int    runningTime = (roomInfo['running_time']     ?? 0) as int;
    final String scoreOpen   = (roomInfo['score_open_range'] ?? 'ALL') as String;

    final String openLabel   = (openYn == 'Y') ? '공개' : '비공개';

    return Dialog(
      backgroundColor: Colors.white,
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(18)),
      child: ConstrainedBox(
        constraints: BoxConstraints(
          maxHeight: media.size.height * 0.8,
          minWidth: media.size.width * 0.8,
        ),
        child: SingleChildScrollView(
          padding: const EdgeInsets.all(20),
          child: Column(
            mainAxisSize: MainAxisSize.min, 
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              // (A) 상단 타이틀
              const Text(
                '방 정보',
                style: TextStyle(
                  fontSize: 18,
                  fontWeight: FontWeight.bold,
                  color: Colors.black,
                ),
              ),
              const Divider(color: Colors.black54),
              const SizedBox(height: 12),

              // (B) 방 제목
              _buildLabelValue(label: '방 제목', value: roomTitle.isNotEmpty ? roomTitle : '(없음)'),
              const SizedBox(height: 14),

              // (C) 방 소개
              const Text(
                '방 소개',
                style: TextStyle(
                  fontSize: 15,
                  fontWeight: FontWeight.bold,
                  color: Colors.black87,
                ),
              ),
              const SizedBox(height: 6),

              // 가로로 꽉 차게(width: double.infinity), 세로 최대 100px → 스크롤
              Container(
                width: double.infinity,
                constraints: const BoxConstraints(maxHeight: 100), 
                decoration: BoxDecoration(
                  border: Border.all(color: Colors.black26),
                  borderRadius: BorderRadius.circular(8),
                ),
                padding: const EdgeInsets.all(8),
                child: SingleChildScrollView(
                  child: Text(
                    roomIntro.isNotEmpty ? roomIntro : '소개글 없음',
                    style: const TextStyle(fontSize: 14, color: Colors.black),
                    softWrap: true,
                  ),
                ),
              ),
              const SizedBox(height: 16),

              // (D) 공개 여부
              _buildLabelValue(label: '공개 여부', value: openLabel),
              const SizedBox(height: 8),

              // (E) 최대 인원
              _buildLabelValue(label: '최대 인원', value: '$maxPeople 명'),
              const SizedBox(height: 8),

              // (F) 운영 시간
              _buildLabelValue(label: '운영 시간', value: '$runningTime 분'),
              const SizedBox(height: 8),

              // (G) 점수 공개 범위
              _buildLabelValue(label: '점수 공개 범위', value: scoreOpen),
              const SizedBox(height: 24),

              // (H) 하단 닫기 버튼 (가운데 정렬)
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  ElevatedButton(
                    onPressed: () => Navigator.pop(context),
                    style: ElevatedButton.styleFrom(
                      backgroundColor: Colors.black,
                      foregroundColor: Colors.white,
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(8),
                      ),
                      padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 12),
                    ),
                    child: const Text('닫기'),
                  ),
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }

  /// label + value를 세로로 배치한 간단 위젯
  Widget _buildLabelValue({
    required String label,
    required String value,
  }) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          label,
          style: const TextStyle(
            fontSize: 15,
            fontWeight: FontWeight.bold,
            color: Colors.black87,
          ),
        ),
        const SizedBox(height: 4),
        Text(
          value,
          style: const TextStyle(fontSize: 14, color: Colors.black),
        ),
      ],
    );
  }
}
