import 'package:flutter/material.dart';

class UserInfoFinishDialog extends StatelessWidget {
  final Map<String, dynamic> userData;

  const UserInfoFinishDialog({Key? key, required this.userData}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // 예: { "nickname": "testuser4", "profile_img": "...", "introduce_myself": "..." }
    final nickname   = (userData['nickname'] ?? '').toString();
    final profileImg = (userData['profile_img'] ?? '').toString();
    final intro      = (userData['introduce_myself'] ?? '').toString().trim();

    return Dialog(
      backgroundColor: Colors.white,
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(16)),
      child: Padding(
        // 좌우여백 좀 더 주고, 세로도 여유롭게
        padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 24),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            // (A) 상단 타이틀
            const Text(
              '유저 정보',
              style: TextStyle(
                fontSize: 18,
                fontWeight: FontWeight.bold,
              ),
            ),
            const SizedBox(height: 16),

            // (B) 프로필 이미지
            Container(
              width: 100,
              height: 100,
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                border: Border.all(color: Colors.black26, width: 1.5),
              ),
              child: ClipOval(
                child: (profileImg.isNotEmpty)
                    ? Image.network(
                        'https://eldsoft.com:8097/images$profileImg',
                        fit: BoxFit.cover,
                        errorBuilder: (ctx, err, st) => 
                          const Center(child: Text('이미지\n오류', textAlign: TextAlign.center, style: TextStyle(fontSize: 12))),
                      )
                    : const Center(
                        child: Text(
                          '이미지\n없음',
                          textAlign: TextAlign.center,
                          style: TextStyle(fontSize: 12),
                        ),
                      ),
              ),
            ),
            const SizedBox(height: 16),

            // (C) 닉네임
            Text(
              nickname.isNotEmpty ? nickname : '유저',
              style: const TextStyle(
                fontSize: 16,
                fontWeight: FontWeight.bold,
              ),
            ),

            const SizedBox(height: 20),

            // (D) 소개 라벨
            const Align(
              alignment: Alignment.centerLeft,
              child: Text(
                '소개',
                style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: 14,
                ),
              ),
            ),
            const SizedBox(height: 6),

            // (E) 소개 내용 (길이에 맞춰 자연스럽게 높이 확장)
            Container(
              width: double.infinity,
              // 최소 60, 최대 200 정도로 제한
              constraints: const BoxConstraints(
                minHeight: 60,
                maxHeight: 200,
              ),
              decoration: BoxDecoration(
                border: Border.all(color: Colors.black26),
                borderRadius: BorderRadius.circular(8),
              ),
              padding: const EdgeInsets.all(8),
              child: SingleChildScrollView(
                child: Text(
                  intro.isNotEmpty ? intro : '소개글이 없습니다.',
                  style: const TextStyle(fontSize: 14),
                ),
              ),
            ),

            const SizedBox(height: 24),

            // (F) 확인 버튼
            SizedBox(
              width: 100,
              child: ElevatedButton(
                onPressed: () => Navigator.pop(context),
                style: ElevatedButton.styleFrom(
                  backgroundColor: Colors.black,
                  foregroundColor: Colors.white,
                  shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(8)),
                  padding: const EdgeInsets.symmetric(vertical: 12),
                ),
                child: const Text('확인', style: TextStyle(fontSize: 14)),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
