import 'package:flutter/material.dart';
import 'dart:async';
import 'package:firebase_database/firebase_database.dart';
import 'package:shared_preferences/shared_preferences.dart';

// 메인 페이지
import 'main_page.dart';

// API
import '../../plugins/api.dart';

// 대화 창
import '../../dialogs/response_dialog.dart';
import '../../dialogs/yes_no_dialog.dart';
import '../../dialogs/room_setting_dialog.dart';
import '../../dialogs/user_info_team_dialog.dart';
import '../../dialogs/team_name_edit_dialog.dart';
import 'playing_team_page.dart';

// 광고
import 'package:google_mobile_ads/google_mobile_ads.dart';

// 설정
import '../../config/config.dart';

class WaitingRoomTeamPage extends StatefulWidget {
  final int roomSeq;
  final String roomType; // "team"

  const WaitingRoomTeamPage({
    Key? key,
    required this.roomSeq,
    required this.roomType,
  }) : super(key: key);

  @override
  State<WaitingRoomTeamPage> createState() => _WaitingRoomTeamPageState();
}

class _WaitingRoomTeamPageState extends State<WaitingRoomTeamPage> {
  // 방 설정
  String roomMasterYn = 'N';
  String roomTitle = '';
  String roomIntro = '';
  String openYn = 'Y';
  String roomPw = '';
  int runningTime = 1;
  int numberOfPeople = 10;
  String scoreOpenRange = 'PRIVATE';
  int numberOfTeams = 1;

  List<String> _teamNameList = [];
  List<Map<String, dynamic>> _userList = [];

  bool _isLoading = true;

  // 서버 요청 로딩중
  bool _isServerRequestLoading = false;

  late DatabaseReference _roomRef;
  Stream<DatabaseEvent>? _roomStream;
  StreamSubscription<DatabaseEvent>? _roomStreamSubscription;

  bool _movedToRunningPage = false;
  bool _kickedOut = false;
  bool _roomTimeOut = false;
  String _roomTimeOutMsg = '';

  String mySeq = '0';

  // (★) 1시간 카운트다운
  Timer? _countdownTimer;
  Duration _remaining = const Duration(hours: 1);
  DateTime? _createDt;

  /// (1) 광고 배너 관련 변수
  BannerAd? _bannerAd;
  bool _isBannerReady = false; // 광고 로드 완료 여부
  String adUnitId = Config.testAdUnitId;

  // 방장 SEQ 저장
  String _masterSeqString = '';

  @override
  void initState() {
    super.initState();
    FirebaseDatabase.instance.goOnline();
    // (C) 배너 광고 초기화
    _initBannerAd();
    // (D) 방 정보 초기화
    _initRoomRef();
  }

  Future<void> _initRoomRef() async {  
    final prefs = await SharedPreferences.getInstance();
    mySeq = prefs.getInt('my_user_seq')?.toString() ?? '0';

    final roomKey = 'korea-${widget.roomSeq}';
    _roomRef = FirebaseDatabase.instance.ref('rooms/$roomKey');

    // onDisconnect + connect_yn='Y'
    final myUserRef = _roomRef.child('userInfo').child(mySeq);
    myUserRef.onDisconnect().update({'connect_yn': 'N'});
    await myUserRef.update({'connect_yn': 'Y'});

    _listenRoomData();
  }

  @override
  void dispose() {
    _countdownTimer?.cancel();
    _roomStreamSubscription?.cancel();
    super.dispose();
  }

  /// 배너 광고 초기화
  void _initBannerAd() {
    _bannerAd = BannerAd(
      size: AdSize.banner, // 일반 배너 사이즈
      // adUnitId: 'ca-app-pub-3940256099942544/6300978111' (테스트용)
      adUnitId: adUnitId, // 실제/테스트 배너 광고 단위 ID
      listener: BannerAdListener(
        onAdLoaded: (Ad ad) {
          setState(() => _isBannerReady = true);
          debugPrint('배너 광고 로드 완료');
        },
        onAdFailedToLoad: (Ad ad, LoadAdError err) {
          debugPrint('배너 광고 로드 실패: $err');
          ad.dispose();
        },
      ),
      request: const AdRequest(),
    );

    // load() 호출로 광고 요청
    _bannerAd?.load();
  }

  void _listenRoomData() {
    _roomStream = _roomRef.onValue;
    _roomStreamSubscription = _roomStream?.listen((event) {
      final snapshot = event.snapshot;
      if (!snapshot.exists) {
        setState(() {
          _isLoading = false;
          roomTitle = '방 정보 없음';
          _userList = [];
        });
        return;
      }

      final data = snapshot.value as Map<dynamic, dynamic>? ?? {};
      final roomInfoData = data['roomInfo'] as Map<dynamic, dynamic>? ?? {};
      // final userInfoData = data['userInfo'] as Map<dynamic, dynamic>? ?? {};
      final userInfoDynamic = data['userInfo']; // 이건 List일 수 있음
      
      final tempList = <Map<String, dynamic>>[];
      // userList
      if (userInfoDynamic is Map) {
        userInfoDynamic.forEach((key, val) {
          if (val is Map) {
            tempList.add({
              'user_seq': val['user_seq'].toString() ?? '0',
              'participant_type': val['participant_type'] ?? '',
              'nickname': val['nickname'] ?? '유저',
              'team_name': val['team_name'] ?? '',
              'score': val['score'] ?? 0,
              'profile_img': val['profile_img'] ?? '',
              'introduce_myself': val['introduce_myself'] ?? '',
              'ready_yn': (val['ready_yn'] ?? 'N').toString().toUpperCase(),
              'connect_yn': (val['connect_yn'] ?? 'Y').toString().toUpperCase(),
            });
          }
        });
      }

      final roomStatus = (roomInfoData['room_status'] ?? 'WAIT').toString().toUpperCase();

      setState(() {
        roomTitle = (roomInfoData['room_title'] ?? '') as String;
        roomIntro = (roomInfoData['room_intro'] ?? '') as String;
        openYn = (roomInfoData['open_yn'] ?? 'Y') as String;
        roomPw = (roomInfoData['room_pw'] ?? '') as String;
        runningTime = _toInt(roomInfoData['running_time'], 1);
        numberOfPeople = _toInt(roomInfoData['number_of_people'], 10);
        scoreOpenRange = (roomInfoData['score_open_range'] ?? 'PRIVATE') as String;
        numberOfTeams = _toInt(roomInfoData['number_of_teams'], 1);

        // 팀명
        final tStr = (roomInfoData['team_name_list'] ?? '') as String;
        if (tStr.isNotEmpty) {
          _teamNameList = tStr.split(',').map((e) => e.trim().toUpperCase()).toList();
        } else {
          _teamNameList = List.generate(numberOfTeams, (i) => String.fromCharCode(65 + i));
        }

        // 방장
        roomMasterYn = 'N';
        final masterSeq = roomInfoData['master_user_seq'];
        if (masterSeq != null && masterSeq.toString() == mySeq) {
          roomMasterYn = 'Y';
        }
        
        if (masterSeq != null) {
          _masterSeqString = masterSeq.toString();
        } else {
          _masterSeqString = ''; 
        }

        _userList = tempList;
        _isLoading = false;
      });

      // 진행중 -> 이동
      if (roomStatus == 'RUNNING' && !_movedToRunningPage) {
        _movedToRunningPage = true;
        Navigator.pushAndRemoveUntil(
          context,
          MaterialPageRoute(
            builder: (_) => PlayingTeamPage(
              roomSeq: widget.roomSeq,
              roomTitle: roomTitle,
            ),
          ),
          (route) => false,
        );
        return;
      }

      // (C) create_dt 파싱 -> 1시간 카운트다운
      final createDtStr = (roomInfoData['create_dt'] ?? '') as String;
      if (createDtStr.isNotEmpty) {
        final dotIndex = createDtStr.indexOf('.');
        final isoStr = createDtStr.substring(0, dotIndex);
        print('isoStr: $isoStr');

        final dt1 = DateTime.tryParse(createDtStr);
        print('dt1: $dt1');
        final dt = DateTime.tryParse(isoStr);
        print('dt: $dt');
        final dt2 = DateTime.parse(isoStr);
        print('dt2: $dt2');
        if (dt != null) {
          setState(() {
            _createDt = dt;
          });
          _startCountdownTimer();
        }
      }

      // 강퇴판별
      final amIStillHere = _userList.any((u) => u['user_seq'].toString() == mySeq);
      if (!amIStillHere && !_kickedOut && roomMasterYn != 'Y') {
        _kickedOut = true;
        if (_roomTimeOut) {
          _roomTimeOutMsg = '방장이 나갔습니다.';
        } else if (_kickedOut) {
          _roomTimeOutMsg = '강퇴되었습니다.';
        }
        Future.delayed(Duration.zero, () async {
          await showResponseDialog(context, '안내', _roomTimeOutMsg);
          Navigator.pushAndRemoveUntil(
            context,
            MaterialPageRoute(builder: (_) => const MainPage()),
            (route) => false,
          );
        });
      }
    }, onError: (error) {
      setState(() {
        _isLoading = false;
        roomTitle = '오류 발생';
      });
    });
  }

  // 카운트다운
  void _startCountdownTimer() {
    if (_countdownTimer != null && _countdownTimer!.isActive) {
      return;
    }
    if (_createDt == null) return;

    _countdownTimer = Timer.periodic(const Duration(seconds: 1), (timer) {
      // final endTime = _createDt!.add(const Duration(hours: 1));
      final endTime = _createDt!.add(const Duration(minutes: 1));
      final now = DateTime.now();
      final diff = endTime.difference(now);

      if (diff.isNegative) {
        timer.cancel();
        _remaining = const Duration(seconds: 0);
        _onAutoTimeout();
      } else {
        setState(() {
          _remaining = diff;
        });
      }
    });
  }

  void _onAutoTimeout() {
    // 자동 종료 -> 방장=나가기(방삭제), 일반=나가기
    setState(() {
      _roomTimeOut = true;
    });
    _requestLeaveRoom();
  }

  Future<void> _requestLeaveRoom() async {
    try {
      final reqBody = {"room_seq": "${widget.roomSeq}"};
      final response = await Api.serverRequest(uri: '/room/score/game/leave', body: reqBody);
      // ...
    } catch (e) {
      // ...
    }
    if (mounted) {
      Navigator.pushAndRemoveUntil(
        context,
        MaterialPageRoute(builder: (_) => const MainPage()),
        (route) => false,
      );
    }
  }

  // 뒤로가기 -> 방 나가기
  Future<void> _onLeaveRoom() async {
    if (roomMasterYn == 'Y') {
      final confirm = await showDialog<bool>(
        context: context,
        barrierDismissible: false,
        builder: (_) {
          return AlertDialog(
            backgroundColor: Colors.white,
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(16),
              side: const BorderSide(color: Colors.black, width: 2),
            ),
            title: const Center(
              child: Text('방 나가기', style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold, color: Colors.black)),
            ),
            content: const Text('방장이 나가면 방은 삭제됩니다.\n정말 나가시겠습니까?', style: TextStyle(fontSize: 14)),
            actionsAlignment: MainAxisAlignment.spaceEvenly,
            actions: [
              TextButton(
                onPressed: () => Navigator.pop(context, false),
                style: TextButton.styleFrom(
                  backgroundColor: Colors.black,
                  foregroundColor: Colors.white,
                  shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(8)),
                ),
                child: const Text('취소'),
              ),
              TextButton(
                onPressed: () {
                  final myUserRef = _roomRef.child('userInfo').child(mySeq);
                  myUserRef.onDisconnect().cancel();
                  Navigator.pop(context, true);
                },
                style: TextButton.styleFrom(
                  backgroundColor: Colors.black,
                  foregroundColor: Colors.white,
                  shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(8)),
                ),
                child: const Text('확인'),
              ),
            ],
          );
        },
      );
      if (confirm != true) return;

      await _requestLeaveRoom();
    } else {
      await _requestLeaveRoom();
    }
  }

  int _toInt(dynamic val, int defaultVal) {
    if (val == null) return defaultVal;
    if (val is int) return val;
    if (val is String) {
      return int.tryParse(val) ?? defaultVal;
    }
    return defaultVal;
  }

  // 상단 버튼
  Widget _buildTopButtons() {
    if (_isLoading) return const SizedBox();

    final me = _userList.firstWhere((u) => (u['user_seq'].toString() ?? '0') == mySeq, orElse: () => {});
    final myReadyYn = (me['ready_yn'] ?? 'N').toString().toUpperCase();
    final bool isReady = (myReadyYn == 'Y');
    final readyLabel = isReady ? '준비완료' : '준비';

    final btnStyle = ElevatedButton.styleFrom(
      backgroundColor: Colors.white,
      foregroundColor: Colors.black,
      side: const BorderSide(color: Colors.black, width: 1),
    );

    if (roomMasterYn == 'Y') {
      return Row(
        children: [
          Expanded(
            child: Container(
              margin: const EdgeInsets.symmetric(horizontal: 4),
              child: ElevatedButton(
                style: btnStyle,
                onPressed: _onOpenRoomSetting,
                child: const Text('방 설정'),
              ),
            ),
          ),
          Expanded(
            child: Container(
              margin: const EdgeInsets.symmetric(horizontal: 4),
              child: ElevatedButton(
                style: btnStyle,
                onPressed: _onToggleReady,
                child: Text(readyLabel),
              ),
            ),
          ),
          Expanded(
            child: Container(
              margin: const EdgeInsets.symmetric(horizontal: 4),
              child: ElevatedButton(
                style: btnStyle,
                onPressed: _isServerRequestLoading ? null : _onGameStart,
                child: _isServerRequestLoading
                    ? const CircularProgressIndicator()
                    : const Text('게임 시작'),
              ),
            ),
          ),
        ],
      );
    } else {
      return Row(
        children: [
          Expanded(
            child: Container(
              margin: const EdgeInsets.symmetric(horizontal: 8),
              child: ElevatedButton(
                style: btnStyle,
                onPressed: _onOpenRoomSetting,
                child: const Text('방 설정'),
              ),
            ),
          ),
          Expanded(
            child: Container(
              margin: const EdgeInsets.symmetric(horizontal: 8),
              child: ElevatedButton(
                style: btnStyle,
                onPressed: _onToggleReady,
                child: Text(readyLabel),
              ),
            ),
          ),
        ],
      );
    }
  }

  Future<void> _onToggleReady() async {
    try {
      final me = _userList.firstWhere((u) => (u['user_seq'].toString() ?? '') == mySeq, orElse: () => {});
      final myReadyYn = (me['ready_yn'] ?? 'N').toString().toUpperCase();
      final isReady = (myReadyYn == 'Y');
      final newYn = isReady ? 'N' : 'Y';

      final userRef = _roomRef.child('userInfo').child(mySeq);
      await userRef.update({"ready_yn": newYn});
    } catch (e) {
      showResponseDialog(context, '오류', 'READY 설정에 실패했습니다.');
    }
  }

  Future<void> _onOpenRoomSetting() async {
    final roomInfo = {
      "room_seq": "${widget.roomSeq}",
      "room_master_yn": roomMasterYn,
      "room_title": roomTitle,
      "room_intro": roomIntro,
      "open_yn": openYn,
      "room_pw": roomPw,
      "running_time": runningTime,
      "room_type": widget.roomType,
      "number_of_people": numberOfPeople,
      "score_open_range": scoreOpenRange,
      "number_of_teams": numberOfTeams,
      "team_name_list": _teamNameList.join(','),
    };

    final result = await showDialog(
      context: context,
      barrierDismissible: false,
      builder: (_) => RoomSettingModal(roomInfo: roomInfo),
    );
    if (result == 'refresh') {
      // ...
    }
  }

  Future<void> _onGameStart() async {
    setState(() => _isServerRequestLoading = true);
    final notReady = _userList.any((u) => (u['ready_yn'] ?? 'N').toString().toUpperCase() != 'Y');
    if (notReady) {
      showResponseDialog(context, '안내', '아직 준비되지 않은 참가자가 있습니다(방장 포함).');
      setState(() => _isServerRequestLoading = false);
      return;
    }

    final requestBody = {
      "room_seq": "${widget.roomSeq}",
      "room_type": "TEAM",
    };
    try {
      final response = await Api.serverRequest(uri: '/room/score/game/start', body: requestBody);
      if (response['result'] == 'OK') {
        final resp = response['response'] ?? {};
        if (resp['result'] == 'OK') {
          print('게임 시작 요청 성공(팀전)');
        } else {
          // 게임 시작 요청 실패
          showResponseDialog(context, '오류', '게임 시작 요청에 실패했습니다.');
        }
      } else {
        // 게임 시작 요청 실패
        showResponseDialog(context, '오류', '게임 시작 요청에 실패했습니다.');
      }
    } catch (e) {
      // 게임 시작 요청 실패
      showResponseDialog(context, '오류', '게임 시작 요청에 실패했습니다.');
    } finally {
      setState(() => _isServerRequestLoading = false);
    }
  }

  // (★) 카운트다운 표시용
  String _formatDuration(Duration d) {
    final mm = d.inMinutes.remainder(60).toString().padLeft(2, '0');
    final ss = d.inSeconds.remainder(60).toString().padLeft(2, '0');
    return '$mm:$ss';
  }

  @override
  Widget build(BuildContext context) {
    final countdownStr = _formatDuration(_remaining);

    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.black,
        elevation: 0,
        // 방 제목 + 남은시간
        title: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            // 왼쪽: 방 제목
            Text(
              roomTitle.isNotEmpty ? roomTitle : '방 제목',
              style: const TextStyle(color: Colors.white),
            ),
            // 오른쪽: 남은시간
            Text(
              countdownStr, // 예: "10:23"
              style: const TextStyle(color: Colors.white),
            ),
          ],
        ),
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
          onPressed: _onLeaveRoom,
        ),
      ),
      bottomNavigationBar:  _isBannerReady && _bannerAd != null
        ? Container(
            color: Colors.white,
            width: _bannerAd!.size.width.toDouble(),
            height: _bannerAd!.size.height.toDouble(),
            child: AdWidget(ad: _bannerAd!),
          )
        : SizedBox.shrink(), // 로딩 전엔 빈 공간 or 원하는 위젯
      body: _isLoading
          ? const Center(child: CircularProgressIndicator())
          : SingleChildScrollView(
              padding: const EdgeInsets.symmetric(vertical: 16, horizontal: 16),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  _buildTopButtons(),
                  const SizedBox(height: 20),

                  // const Text('사회자', style: TextStyle(fontSize: 16, fontWeight: FontWeight.bold, color: Colors.black)),
                  // const SizedBox(height: 8),
                  // _buildAdminSection(),
                  // const SizedBox(height: 20),

                  const Text('팀별 참가자', style: TextStyle(fontSize: 16, fontWeight: FontWeight.bold, color: Colors.black)),
                  const SizedBox(height: 8),
                  _buildTeamSection(),
                  const SizedBox(height: 20),

                  _buildWaitSection(),
                ],
              ),
            ),
    );
  }

  // Widget _buildAdminSection() {
  //   final adminList = _userList.where((u) {
  //     final pType = (u['participant_type'] ?? '').toString().toUpperCase();
  //     return pType == 'ADMIN';
  //   }).toList();

  //   return Container(
  //     padding: const EdgeInsets.all(8),
  //     decoration: BoxDecoration(
  //       color: Colors.white,
  //       border: Border.all(color: Colors.black),
  //       borderRadius: BorderRadius.circular(8),
  //     ),
  //     child: adminList.isEmpty
  //         ? const Text('사회자가 없습니다.', style: TextStyle(color: Colors.black))
  //         : Wrap(
  //             spacing: 16,
  //             runSpacing: 8,
  //             children: adminList.map(_buildSeat).toList(),
  //           ),
  //   );
  // }

  Widget _buildTeamSection() {
    // final players = _userList.where((u) {
    //   final pType = (u['participant_type'] ?? '').toString().toUpperCase();
    //   return (pType != 'ADMIN');
    // }).toList();
    final players = _userList.toList();

    final Map<String, List<Map<String, dynamic>>> teamMap = {};
    for (final tName in _teamNameList) {
      teamMap[tName] = [];
    }

    for (var user in players) {
      final tName = (user['team_name'] ?? '').toString().trim().toUpperCase();
      if (tName.isNotEmpty && tName != 'WAIT' && teamMap.containsKey(tName)) {
        teamMap[tName]!.add(user);
      }
    }

    if (teamMap.isEmpty) {
      return Container(
        padding: const EdgeInsets.all(8),
        decoration: BoxDecoration(
          color: Colors.white,
          border: Border.all(color: Colors.black),
          borderRadius: BorderRadius.circular(8),
        ),
        child: const Text('팀에 배정된 참가자가 없습니다.', style: TextStyle(color: Colors.black)),
      );
    }

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: _teamNameList.map((teamName) {
        final members = teamMap[teamName]!;

        return Container(
          margin: const EdgeInsets.only(bottom: 16),
          decoration: BoxDecoration(
            color: Colors.white,
            border: Border.all(color: Colors.black),
            borderRadius: BorderRadius.circular(8),
          ),
          child: Column(
            children: [
              GestureDetector(
                onTap: () async {
                  if (roomMasterYn == 'Y') {
                    final result = await showDialog(
                      context: context,
                      barrierDismissible: false,
                      builder: (_) => TeamNameEditModal(
                        roomSeq: widget.roomSeq,
                        roomTypeName: 'TEAM',
                        beforeTeamName: teamName,
                        existingTeamNames: _teamNameList,
                      ),
                    );
                    if (result == 'refresh') {
                      // ...
                    }
                  }
                },
                child: Container(
                  width: double.infinity,
                  padding: const EdgeInsets.symmetric(vertical: 8),
                  color: Colors.black,
                  child: Center(
                    child: Text(
                      '팀 $teamName',
                      style: const TextStyle(color: Colors.white, fontWeight: FontWeight.bold),
                    ),
                  ),
                ),
              ),
              SingleChildScrollView(
                scrollDirection: Axis.horizontal,
                padding: const EdgeInsets.all(8),
                child: Row(children: members.map(_buildSeat).toList()),
              ),
            ],
          ),
        );
      }).toList(),
    );
  }

  Widget _buildWaitSection() {
    final waitList = _userList.where((u) {
      final pType = (u['participant_type'] ?? '').toString().toUpperCase();
      // if (pType == 'ADMIN') return false;
      final tName = (u['team_name'] ?? '').toString().toUpperCase();
      return (tName.isEmpty || tName == 'WAIT');
    }).toList();

    if (waitList.isEmpty) return const SizedBox();

    return Container(
      margin: const EdgeInsets.only(bottom: 16),
      decoration: BoxDecoration(
        color: Colors.white,
        border: Border.all(color: Colors.black),
        borderRadius: BorderRadius.circular(8),
      ),
      child: Column(
        children: [
          Container(
            width: double.infinity,
            padding: const EdgeInsets.symmetric(vertical: 8),
            color: Colors.black,
            child: const Center(
              child: Text('대기중', style: TextStyle(color: Colors.white, fontWeight: FontWeight.bold)),
            ),
          ),
          SingleChildScrollView(
            scrollDirection: Axis.horizontal,
            padding: const EdgeInsets.all(8),
            child: Row(children: waitList.map(_buildSeat).toList()),
          ),
        ],
      ),
    );
  }

  Widget _buildSeat(Map<String, dynamic> user) {
    final userName = user['nickname'] ?? '유저';
    final profileImg = user['profile_img'] ?? '';
    final readyYn = (user['ready_yn'] ?? 'N').toString().toUpperCase();
    final connectYn = (user['connect_yn'] ?? 'Y').toString().toUpperCase();
    final bool isReady = (readyYn == 'Y');
    final bool isDisconnected = (connectYn == 'N');
    final bool isMaster = (roomMasterYn == 'Y');

    // user가 방장인지 확인
    final isRoomMasterUser = (user['user_seq']?.toString() ?? '') == _masterSeqString;
    // user가 사회자인지 확인
    final participantType = (user['participant_type'] ?? '').toString().toUpperCase();
    final isAdmin = (participantType == 'ADMIN');

    // 아이콘 붙이기
    String roleIcon = '';
    if (isRoomMasterUser) {
      // 방장
      roleIcon = '★ ';
    } else if (isAdmin) {
      // 사회자
      roleIcon = '☆ ';
    }

    final displayName = '$roleIcon$userName';

    return GestureDetector(
      onTap: () async {
        final result = await showDialog(
          context: context,
          barrierDismissible: false,
          builder: (_) => UserInfoTeamDialog(
            userData: user,
            isRoomMaster: isMaster,
            roomSeq: widget.roomSeq,
            roomTypeName: widget.roomType.toUpperCase(),
            teamNameList: _teamNameList,
          ),
        );
        if (result == 'refresh') {
          // ...
        }
      },
      child: Container(
        width: 60,
        margin: const EdgeInsets.only(right: 8),
        child: Column(
          children: [
            Container(
              width: 50,
              height: 50,
              decoration: BoxDecoration(
                color: Colors.white,
                border: Border.all(
                  color: isDisconnected
                      ? Colors.orange
                      : (isReady ? Colors.red : Colors.black),
                  width: isDisconnected ? 2 : (isReady ? 2 : 1),
                ),
                borderRadius: BorderRadius.circular(20),
                boxShadow: [
                  if (isReady)
                    BoxShadow(
                      color: Colors.redAccent.withOpacity(0.6),
                      blurRadius: 8,
                      spreadRadius: 2,
                    ),
                  if (isDisconnected)
                    BoxShadow(
                      color: Colors.orangeAccent.withOpacity(0.6),
                      blurRadius: 8,
                      spreadRadius: 2,
                    ),
                ],
              ),
              child: ClipRRect(
                borderRadius: BorderRadius.circular(20),
                child: isDisconnected
                    ? const Center(
                        child: Text(
                          '!',
                          style: TextStyle(
                            fontSize: 20,
                            color: Colors.orange,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                      )
                    : Image.network(
                        'https://eldsoft.com:8097/images$profileImg',
                        fit: BoxFit.cover,
                        errorBuilder: (_, __, ___) => const Center(
                          child: Text(
                            '이미지\n불가',
                            textAlign: TextAlign.center,
                            style: TextStyle(fontSize: 10),
                          ),
                        ),
                      ),
              ),
            ),
            const SizedBox(height: 2),
            Text(displayName, style: const TextStyle(fontSize: 12, color: Colors.black)),
          ],
        ),
      ),
    );
  }
}
